==> flutter_widget_from_html_core-0.5.0-rc.2020081901.tar.gz: lib/src/internal/ops/style_margin.dart <==
part of '../core_ops.dart';

const kCssMargin = 'margin';

Widget _marginHorizontalBuilder(Widget w, CssLengthBox b, TextStyleHtml tsh) =>
    Padding(
      child: w,
      padding: EdgeInsets.only(
        left: b.getValueLeft(tsh) ?? 0.0,
        right: b.getValueRight(tsh) ?? 0.0,
      ),
    );

class StyleMargin {
  final WidgetFactory wf;

  StyleMargin(this.wf);

  BuildOp get buildOp => BuildOp(
        isBlockElement: false,
        onPieces: (meta, pieces) {
          if (meta.isBlockElement) return pieces;
          final m = tryParseCssLengthBox(meta, kCssMargin);
          if (m?.hasLeftOrRight != true) return pieces;

          return _wrapTextBits(
            pieces,
            appendBuilder: (parent) =>
                TextWidget(parent, _paddingInlineAfter(parent.tsb, m)),
            prependBuilder: (parent) =>
                TextWidget(parent, _paddingInlineBefore(parent.tsb, m)),
          );
        },
        onWidgets: (meta, widgets) {
          if (widgets?.isNotEmpty != true) return null;
          final m = tryParseCssLengthBox(meta, kCssMargin);
          if (m == null) return null;

          final t = m.top?.isNotEmpty == true;
          final b = m.bottom?.isNotEmpty == true;
          final ws = List<WidgetPlaceholder>(
              (t ? 1 : 0) + widgets.length + (b ? 1 : 0));
          final tsb = meta.tsb();

          var i = 0;
          if (t) ws[i++] = HeightPlaceholder(m.top, tsb);

          for (final widget in widgets) {
            if (m.hasLeftOrRight) {
              widget.wrapWith(
                  (c, w) => _marginHorizontalBuilder(w, m, tsb.build(c)));
            }

            ws[i++] = widget;
          }

          if (b) ws[i++] = HeightPlaceholder(m.bottom, tsb);

          return ws;
        },
        priority: 99999,
      );
}

==> flutter_widget_from_html_core-0.5.1.tar.gz: lib/src/internal/ops/style_margin.dart <==
part of '../core_ops.dart';

const kCssMargin = 'margin';

Widget _marginHorizontalBuilder(Widget w, CssLengthBox b, TextStyleHtml tsh) =>
    Padding(
      child: w,
      padding: EdgeInsets.only(
        left: b.getValueLeft(tsh) ?? 0.0,
        right: b.getValueRight(tsh) ?? 0.0,
      ),
    );

class StyleMargin {
  final WidgetFactory wf;

  StyleMargin(this.wf);

  BuildOp get buildOp => BuildOp(
        onTree: (meta, tree) {
          if (meta.willBuildSubtree) return;
          final m = tryParseCssLengthBox(meta, kCssMargin);
          if (m?.hasLeftOrRight != true) return;

          return wrapTree(
            tree,
            append: (p) => WidgetBit.inline(p, _paddingInlineAfter(p.tsb, m)),
            prepend: (p) => WidgetBit.inline(p, _paddingInlineBefore(p.tsb, m)),
          );
        },
        onWidgets: (meta, widgets) {
          if (widgets?.isNotEmpty != true) return null;
          final m = tryParseCssLengthBox(meta, kCssMargin);
          if (m == null) return null;

          final t = m.top?.isNotEmpty == true;
          final b = m.bottom?.isNotEmpty == true;
          final ws = List<WidgetPlaceholder>(
              (t ? 1 : 0) + widgets.length + (b ? 1 : 0));
          final tsb = meta.tsb();

          var i = 0;
          if (t) ws[i++] = HeightPlaceholder(m.top, tsb);

          for (final widget in widgets) {
            if (m.hasLeftOrRight) {
              widget.wrapWith(
                  (c, w) => _marginHorizontalBuilder(w, m, tsb.build(c)));
            }

            ws[i++] = widget;
          }

          if (b) ws[i++] = HeightPlaceholder(m.bottom, tsb);

          return ws;
        },
        onWidgetsIsOptional: true,
        priority: 99999,
      );
}
